# OrdinaryGacha
OrdinaryGacha เป็นแพ็กเกจสำหรับช่วยในการทำระบบสุ่มกาชาธรรมดา
## ความสามารถของแพ็กเกจ
- เพิ่มไอเทมในระบบกาชาโดยสามารถกำหนดอัตราดรอป สำหรับไอเทมแต่ละชิ้นได้
- แสดงไอเทมทั้งหมดที่มีในระบบกาชา
- ลบไอเทมที่ต้องการออกจากระบบกาชาด้วยชื่อไอเทม
- สุ่มไอเทมตามอัตราดรอปที่กำหนด
## วิธีติดตั้ง
```sh
pip install OrdinaryGacha
```
